@@ -15,11 +15,11 @@ use File::Spec;
 use IO            qw( File );
 use Unicode::UCD  qw( charscript );
 
-use Test2::API qw( context );
+use Test2::API 1.302200 qw( context );
 
 our @EXPORT_OK = qw( all_perl_files_scripts_ok file_scripts_ok );
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 
 sub file_scripts_ok {
@@ -180,7 +180,7 @@ Test::MixedScripts - test text for mixed and potentially confusable Unicode scri
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 SYNOPSIS
 
